==================
Contribution Guide
==================

*********************************
Welcome in our Contribution Guide
*********************************

Contributions are welcome, and they are greatly appreciated!

Every little bit helps a lot, and credit will always be given.

*********************
How can i contribute?
*********************

You can contribute and help in many ways.

Types of Contributions
======================

Submit Feedback
---------------

The best way to send feedback is to file an issue at https://gitlab.com/paip-web/pwbs/issues .

Issue template is in another section of that document.

If you are proposing a feature explain in detail how it would work.

Write Documentation
-------------------

PWBS (PAiP Web Build System) could always use more documentation and always can have better constructed documentation. Whether as part of official PWBS docs, in docstrings, or even on the web in blog posts, articles, and such.

If you find mistyped word then file an issue or change and submit merge request.

Report Bugs
-----------

Report bugs at https://gitlab.com/paip-web/pwbs/issues .

Issue template is in another section of that document.

If you are reporting a bug, please include:

* Your operating system name and version

* Any details about your local setup that might be helpful in troubleshooting.

* Detailed steps to reproduce bug.

In FUTURE: is planned easier steps to make that way.
Maybe it will be like that:

* Run pwbs like you tried but with flag --bug-mode and add result pwbs.bug.json to issue.

* Any details about your local setup that might be helpful in troubleshooting.

* Detailed steps to reproduce bug.








